@@ -39,5 +39,8 @@ class Config:
     def get_province_abbreviation(self):
         return self.config["province_abbreviation"]
 
+    def get_sms_config(self):
+        return self.config["sms_config"]
+
 
 config = Config()
