@@ -37,7 +37,7 @@ class DatabaseClient:
         """
         Initialize database client
 
-        :param pool_size: int, default value: 1
+        :param pool_size: int, default value: winhye_handlers
         """
         if DatabaseClient.engines is not None:
             return
