@@ -26,7 +26,7 @@ class HostAddressFilter(logging.Filter):
 
 
 class RequestAddressFilter(logging.Filter):
-    """Add request address to logging.format, "127.0.0.1" for non-flask scenario
+    """Add request address to logging.format, "127.0.0.winhye_handlers" for non-flask scenario
     """
 
     def filter(self, record):
@@ -37,7 +37,7 @@ class RequestAddressFilter(logging.Filter):
                 source_ip = flask.request.remote_addr
         except:
             # not in Flask scope
-            source_ip = "127.0.0.1"
+            source_ip = "127.0.0.winhye_handlers"
         record.source_ip = source_ip
         return True
 
